pub struct ParsedResult {
pub ref_date: DateTime<Local>,
pub index: usize,
pub end_index: usize,
pub text: String,
pub start: FastComponents,
pub end: Option<FastComponents>,
}Expand description
A parsed result representing a matched date/time expression.
Fields
ref_date: DateTime<Local>Reference date used while resolving this result.
index: usizeStart byte index of the matched text.
end_index: usizeEnd byte index of the matched text.
text: StringOriginal text slice that produced this result.
start: FastComponentsParsed components for the start of the match.
end: Option<FastComponents>Parsed components for the end of the match, when the result is a range.
Implementations
Sourceimpl ParsedResult
impl ParsedResult
Sourcepub fn new(
reference: &ReferenceWithTimezone,
index: usize,
text: impl Into<String>,
start: FastComponents,
end: Option<FastComponents>,
) -> Self
pub fn new( reference: &ReferenceWithTimezone, index: usize, text: impl Into<String>, start: FastComponents, end: Option<FastComponents>, ) -> Self
Create a parsed result from a matched slice and component set.