ReferenceWithTimezone

Struct ReferenceWithTimezone 

pub struct ReferenceWithTimezone {
    pub instant: DateTime<Local>,
    pub timezone_offset: Option<i32>,
}
Reference date/time with timezone information.

Relative expressions are resolved against this instant and optional timezone offset.

Fields

instant: DateTime<Local>

The reference instant used as the base for relative parsing.

timezone_offset: Option<i32>

Explicit timezone offset in minutes.

None means the system timezone of instant should be used.

Implementations

Source

impl ReferenceWithTimezone

pub fn new(instant: DateTime<Local>, timezone_offset: Option<i32>) -> Self

Create a new reference value from an instant and optional offset.

pub fn now() -> Self

Create a reference value using the current local time.

pub fn get_timezone_offset(&self) -> i32

Return the effective timezone offset in minutes.

pub fn get_system_timezone_adjustment( &self, date: Option<DateTime<Local>>, override_offset: Option<i32>, ) -> i32

Compute the adjustment between the current system offset and a target offset.