pub struct ReferenceWithTimezone {
pub instant: DateTime<Local>,
pub timezone_offset: Option<i32>,
}Expand description
Reference date/time with timezone information.
Relative expressions are resolved against this instant and optional timezone offset.
Fields
instant: DateTime<Local>The reference instant used as the base for relative parsing.
timezone_offset: Option<i32>Explicit timezone offset in minutes.
None means the system timezone of instant should be used.
Implementations